@@ -11,15 +11,6 @@ def read_config(filename: str) -> configparser.ConfigParser:
     return conf
 
 
-def format_value(value: Union[str, int, float]) -> Union[float, int, str]:
-    value = str2num(value)
-    if value < 0.001 or value > 1e3:
-        return "{:,.2e}".format(value)
-    if isinstance(value, int):
-        return value
-    return round(float(value), 3)
-
-
 def format_msg(msg_in: Union[str, list]) -> str:
     msg = msg_in[0] if isinstance(msg_in, list) else msg_in
     if not msg.endswith("."):
@@ -33,15 +24,6 @@ def format_msg(msg_in: Union[str, list]) -> str:
     return msg
 
 
-def str2num(value: Union[str, int, float]) -> Union[float, int]:
-    if not isinstance(value, str):
-        return value
-    try:
-        return int(value)
-    except ValueError:
-        return float(value)
-
-
 def create_expected_received_msg(variable: str, expected: str, received: str) -> str:
     return f"Expected '{expected}' but received '{received}' with variable '{variable}'"
 
@@ -56,3 +38,7 @@ def create_out_of_bounds_msg(
         f"Value {format_value(value)} exceeds expected limits {format_value(lower_limit)} ... "
         f"{format_value(upper_limit)} with variable '{variable}'"
     )
+
+
+def format_value(value: Union[str, int, float]) -> str:
+    return "{:,g}".format(float(value))
